@@ -8,7 +8,8 @@ __docformat__ = "restructuredtext en"
 
 from cubicweb.entities import AnyEntity, fetch_config
 from cubicweb.entities.adapters import ITreeAdapter
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
+
 
 class Zone(AnyEntity):
     """customized class for Zone entities"""
